@@ -1,12 +1,11 @@
 import struct
 
 from msgpack import packb, unpackb
+from msgpack.fallback import Packer as PurePacker
 
 
 def load_length(data_stream, struct_type):
-    length = struct.unpack(struct_type, data_stream.read(struct.calcsize(struct_type)))[
-        0
-    ]
+    length = struct.unpack(struct_type, data_stream.read(struct.calcsize(struct_type)))[0]
     return data_stream.read(length)
 
 
@@ -51,6 +50,49 @@ def msg_pack(data):
     return serialized, len(serialized)
 
 
+class KKExPacker(PurePacker):
+    KEYS_TO_OVERRIDE = {
+        0,
+        1,
+        2,
+        3,
+        4,
+        5,
+        6,
+        "AllCharaOverlayTable",
+        "BreathingBPM",
+        "CurrentCrest",
+        "EnableBulge",
+        "InmonLevel",
+        "LeaveSchoolWeek",
+        "MenstruationSchedule",
+        "ReferralIndex",
+        "ResizeCentroid",
+        "ReturnToSchoolWeek",
+        "SemenVolume",
+        "clothingOffsetVersion",
+    }
+
+    def _pack_map_pairs(self, n, pairs, nest_limit):
+        self._pack_map_header(n)
+        for k, v in pairs:
+            if k in self.KEYS_TO_OVERRIDE and isinstance(k, int):
+                self._buffer.write(b"\xd2" + struct.pack(">i", k))
+            else:
+                self._pack(k, nest_limit - 1)
+
+            if k in self.KEYS_TO_OVERRIDE and isinstance(v, int):
+                self._buffer.write(b"\xd2" + struct.pack(">i", v))
+            else:
+                self._pack(v, nest_limit - 1)
+
+
+def msg_pack_kkex(data):
+    packer = KKExPacker(use_single_float=True, use_bin_type=True)
+    serialized = packer.pack(data)
+    return serialized, len(serialized)
+
+
 def get_png_length(png_data, orig=0):
     idx = orig
     assert png_data[idx : idx + 8] == b"\x89\x50\x4e\x47\x0d\x0a\x1a\x0a"
